@@ -1,6 +1,6 @@
 #!/bin/sh
 #set -xv
-UPGRADE_VER="1.0.11"
+UPGRADE_VER="1.0.10"
 TARGET_PREFIX=sp80_upgrade_
 BIN_PATH=/home/root
 CARD_PATH=${MOUNTR}
@@ -61,32 +61,6 @@ do_reboot() {
   sleep 300
 }
 
-do_sys_check() {
- chk_name=${CARD_PATH}/${1}
- chk_len=$(ls -l $chk_name | awk '{split($0,x," ");printf("%s",x[5])}')
- dd_len=$(($chk_len/512+1))
- chk_hash="n/a"
- #chk_hash=`dd if=$OUT_DD_DEV skip=$2 count=$dd_len | head -c $chk_len | md5sum | awk '{split($0,x," ");printf("%s",x[1])}'`
- $NAND_WR -d ${OUT_DD_DEV} -o $2 -r ${chk_name}.out ${chk_len} | tee -a ${LOG}
- if [ $? -eq 0 ]; then
-  chk_hash=`cat ${chk_name}.out | md5sum | awk '{split($0,x," ");printf("%s",x[1])}'`
- fi
- orig_hash=`cat $chk_name.md5 | awk '{split($0,x," ");printf("%s",x[1])}'`
- echo "chk_name $chk_name chk_len $chk_len dd_len $dd_len skip $2" | tee -a ${LOG}
- echo "chk_hash  $chk_hash" | tee -a ${LOG}
- echo "orig_hash $orig_hash" | tee -a ${LOG}
-
- if [ "${chk_hash}" != "${orig_hash}" ]; then
-  echo "$1 md5sum error" | tee -a ${LOG}
-  echo "Ending upgrade script at " $(date) | tee -a ${LOG}
-  echo "UERR 1" > /proc/sp4
-  flash_erase ${OUT_CHAR_DEV} $2 | tee -a ${LOG}
-  do_reboot 1 "Error 1.5"
- else 
-  echo "$1 md5sum Ok" | tee -a ${LOG}
- fi
-}
-
 copy_app() {
 
 if [ -f ${1} ];
@@ -372,14 +346,6 @@ fi
 
     #
     echo "fl_kupl=$fl_kupl" | tee -a ${LOG}
-
-    #do_sys_check ${BOOT_NAME} 8192
-    #do_sys_check ${KERN_NAME} 16384
-    #do_sys_check ${RFS_NAME} 32768
-    do_sys_check ${BOOT_NAME} 0x400000
-    do_sys_check ${KERN_NAME} 0x800000
-    do_sys_check ${RFS_NAME} 0x1000000
-
     if [ "$fl_kupl" -eq "1" ]; then
          echo "UCMD KUPL" > /proc/sp4
       if [ "$smod" -eq "6" ]; then
